/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */

import cors from "@fastify/cors";
import fastify from "fastify";
import { logger } from "./utils/logger.js";

/**
 * Starts up a web server for health monitoring.
 */
try {
  const server = fastify({
    logger: false,
  });

  server.register(cors, {
    origin: "*",
  });

  server.get("/", async(_request, reply) => {
    reply.send({ message: "Hello, world!" });
  });

  server.listen({ port: 12_346 }, (error) => {
    if (error) {
      void logger.error("instantiate server", error);
      return;
    }
    void logger.log("debug", "Server listening on port 12346.");
  });
} catch (error) {
  if (error instanceof Error) {
    void logger.error("instantiate server", error);
  } else {
    void logger.error("instantiate server", new Error("Unknown error"));
  }
}
